es-configly
=============

config manager using elasticsearch.

```
pip install es-configly
```

## Licence

[MIT](https://github.com/kotsutsumi/es-configly/blob/main/LICENSE)

## Author

[kotsutsumi](https://github.com/kotsutsumi)
